@@ -2,6 +2,9 @@ ACCOUNT = 'account'
 CHARACTER = 'char'
 CORPORATION = 'corp'
 
+BLUEPRINT_ORIGINAL = -1
+BLUEPRINT_COPY = -2
+
 _role_type_bases = {
     'global': '',
     'at_hq': 'AtHQ',
@@ -10,11 +13,11 @@ _role_type_bases = {
 }
 
 class Char(object):
-    corp_roles = dict((k, 'corporationRoles' + v) for k,v in _role_type_bases.iteritems())
+    corp_roles = dict((k, 'corporationRoles' + v) for k,v in _role_type_bases.items())
 
 class Corp(object):
-    role_types = dict((k, 'roles' + v) for k,v in _role_type_bases.iteritems())
-    grantable_types = dict((k, 'grantableRoles' + v) for k,v in _role_type_bases.iteritems())
+    role_types = dict((k, 'roles' + v) for k,v in _role_type_bases.items())
+    grantable_types = dict((k, 'grantableRoles' + v) for k,v in _role_type_bases.items())
 
     pos_states = ('unanchored', 'anchored', 'onlining', 'reinforced', 'online')
 
@@ -26,7 +29,7 @@ class Corp(object):
         )
 
 class Industry(object):
-    job_status = ('failed', 'delivered', 'gm-aborted', 'inflight-unanchored', 'destroyed')
+    job_status = ('failed', 'delivered', 'aborted', 'gm-aborted', 'inflight-unanchored', 'destroyed')
 
 class Market(object):
     order_status = ('active', 'closed', 'expired', 'cancelled', 'pending', 'deleted')
