@@ -7,73 +7,6 @@ class EVE(object):
     def __init__(self, api=None):
         self.api = api
 
-    @api.auto_call('eve/CertificateTree')
-    def certificate_tree(self, api_result=None):
-        """Returns a list of certificates in eve."""
-
-        result = {}
-        rowset = api_result.result.find('rowset')
-        categories = rowset.findall('row')
-
-        for category in categories:
-            cat_attr = category.attrib
-            cat_name = cat_attr['categoryName']
-            cat_tree = {
-                'name': cat_name,
-                'id': int(cat_attr['categoryID']),
-                'classes': {},
-            }
-
-            cls_rowset = category.find('rowset')
-            classes = cls_rowset.findall('row')
-            for cls in classes:
-                cls_attr = cls.attrib
-                cls_name = cls_attr['className']
-                cls_def = {
-                    'name': cls_name,
-                    'id': int(cls_attr['classID']),
-                    'certificates': {}
-                }
-
-                cert_rowset = cls.find('rowset')
-                certificates = cert_rowset.findall('row')
-                for cert in certificates:
-                    cert_attr = cert.attrib
-                    cert_id = int(cert_attr['certificateID'])
-                    cert_entry = {
-                      'id': cert_id,
-                      'grade': int(cert_attr['grade']),
-                      'corp_id': int(cert_attr['corporationID']),
-                      'description': cert_attr['description'],
-                      'required_skills': {},
-                      'required_certs': {}
-                    }
-
-                    req_rowsets = {}
-                    for rowset in cert.findall('rowset'):
-                      req_rowsets[rowset.attrib['name']] = rowset
-
-                    req_skills = req_rowsets['requiredSkills'].findall('row')
-                    for skill in req_skills:
-                        cert_entry['required_skills'][
-                          int(skill.attrib['typeID'])
-                        ] = int(skill.attrib['level'])
-
-                    req_certs = req_rowsets['requiredCertificates'].findall('row')
-                    for req_cert in req_certs:
-                        cert_entry['required_certs'][
-                          int(req_cert.attrib['certificateID'])
-                        ] = int(req_cert.attrib['grade'])
-
-
-                    cls_def['certificates'][cert_id] = cert_entry
-
-                cat_tree['classes'][cls_name] = cls_def
-
-            result[cat_name] = cat_tree
-
-        return api.APIResult(result, api_result.timestamp, api_result.expires)
-
     @api.auto_call('eve/CharacterName', map_params={'id_list': 'IDs'})
     def character_names_from_ids(self, id_list, api_result=None):
         """Retrieve a dict mapping character IDs to names.
