@@ -7,7 +7,8 @@ class Map(object):
     def __init__(self, api=None):
         self.api = api
 
-    def jumps_by_system(self):
+    @api.auto_call('map/Jumps')
+    def jumps_by_system(self, api_result=None):
         """Get jump counts for systems in the last hour.
 
         Returns a tuple of ({system:jumps...}, timestamp).
@@ -15,8 +16,6 @@ class Map(object):
         NOTE: Systems with 0 jumps in the last hour are not included!
         """
 
-        api_result = self.api.get('map/Jumps')
-
         rowset = api_result.result.find('rowset')
         results = {}
         for row in rowset.findall('row'):
@@ -28,16 +27,15 @@ class Map(object):
 
         return api.APIResult((results, data_time), api_result.timestamp, api_result.expires)
 
-    def kills_by_system(self):
+    @api.auto_call('map/Kills')
+    def kills_by_system(self, api_result=None):
         """Get kill counts for systems in the last hour.
 
         Returns a tuple of ({system:{killdata}, timestamp).
 
         Each {killdata} is {'faction':count, 'ship':count, 'pod':count}.
         """
-
-        api_result = self.api.get('map/Kills')
-
+        
         rowset = api_result.result.find('rowset')
         results = {}
         for row in rowset.findall('row'):
@@ -57,11 +55,9 @@ class Map(object):
 
         return api.APIResult((results, data_time), api_result.timestamp, api_result.expires)
 
-    def faction_warfare_systems(self):
+    @api.auto_call('map/FacWarSystems')
+    def faction_warfare_systems(self, api_result=None):
         """Get a dict of factional warfare systems and their info."""
-
-        api_result = self.api.get('map/FacWarSystems')
-
         rowset = api_result.result.find('rowset')
         results = {}
         for row in rowset.findall('row'):
@@ -83,11 +79,9 @@ class Map(object):
 
         return api.APIResult(results, api_result.timestamp, api_result.expires)
 
-    def sov_by_system(self):
+    @api.auto_call('map/Sovereignty')
+    def sov_by_system(self, api_result=None):
         """Get sovereignty info keyed by system."""
-
-        api_result = self.api.get('map/Sovereignty')
-
         rowset = api_result.result.find('rowset')
         results = {}
         for row in rowset.findall('row'):
